@@ -10,30 +10,36 @@
 #' @details
 #' In detail, this procedure reads the name of an input file from the local file system,
 #' or takes a data frame and writes it to the local file system formatted
-#' for the iMRMC program (found at https://github.com/DIDSR/iMRMC/releases), it executes the iMRMC
-#' program which writes the results to the local files system, it reads the analysis results from
+#' for the iMRMC program (found at https://github.com/DIDSR/iMRMC/releases), it executes a java app,
+#' the iMRMC engine, which writes the results to the local files system, it reads the analysis results from
 #' the local file system, packs the analysis results into a list object, deletes the data and analysis results
 #' from the local file system, and returns the list object.
 #' 
-#' The examples took too long for CRAN to accept. So here is an example:
+#' This software requires Java JDK 1.7 or higher.
+#' 
+#' The examples took too long for CRAN to accept. So here is an example: 
+#' \preformatted{
 #' # Create a sample configuration file
 #' config <- sim.gRoeMetz.config()
 #' # Simulate an MRMC ROC data set
 #' dFrame.imrmc <- sim.gRoeMetz(config)
 #' # Analyze the MRMC ROC data
 #' result <- doIMRMC(dFrame.imrmc)
-
+#' }
 #'
 #' @param data This data.frame contains the following variables:
-#'            readerID       [Factor] w/ nR levels "reader1", "reader2", ...
-#'            caseID         [Factor] w/ nC levels "case1", "case2", ...
-#'            modalityID     [Factor] w/ 1 level simRoeMetz.config$modalityID
-#'            score          [num] reader score
-#'            each row of this data frame corresponds to an observation
-#'            for every caseID, there must be a row corresponding to the truth observation
-#'              the readerID for a truth observation is "truth"
-#'              the modalityID for a truth observation is "truth"
-#'              the score for a truth observation must be either 0 (signal-absent) or 1 (signal-present)
+#' \itemize{
+#'   \item \code{readerID} [Factor] with levels like "reader1", "reader2", ...
+#'   \item \code{caseID} [Factor] with levels like "case1", "case2", ...
+#'   \item \code{modalityID} [Factor] with levels like "modality1", "modality2", ...
+#'   \item \code{score} [num] reader score
+#' }
+#'                      
+#' Each row of this data frame corresponds to an observation.
+#' For every caseID, there must be a row corresponding to the truth observation.
+#' The readerID for a truth observation is "truth".
+#' The modalityID for a truth observation is "truth".
+#' The score for a truth observation must be either 0 (signal-absent) or 1 (signal-present).
 #'
 #' @param fileName This character string identifies the location of an iMRMC input file.
 #'   The input file is identical to data except there is a free text section to start,
@@ -47,52 +53,49 @@
 #'            this jar file can be downloaded from https://github.com/DIDSR/iMRMC/releases
 #'            this R program supports version iMRMC-v3p2.jar
 #'
-#' @param stdout where output to 'stdout' or 'stderr' should be sent.
-#'            Possible values are "", to the R console (the default),
-#'            NULL or FALSE (discard output),
-#'            TRUE (capture the output in character vector)
-#'            or a character string naming a file.
-#'
-#' @param stderr where output to 'stdout' or 'stderr' should be sent.
-#'            Possible values are "", to the R console (the default),
-#'            NULL or FALSE (discard output),
-#'            TRUE (capture the output in a character vector)
-#'            or a character string naming a file.
-#'
 #' @param stripDatesForTests Since results include a date and time stamp, these need to be
 #'            stripped out when doing the package tests. This parameter flags whether or not
 #'            the dates should be stripped out.
 #'
-#' @return iMRMCoutput [list] the objects of this list are described in detail in the iMRMC documentation
+#' @return [list] 
+#'            iMRMC outputs. The objects of this list are described in detail in the iMRMC documentation
 #'            which can be found at <http://didsr.github.io/iMRMC/000_iMRMC/userManualHTML/index.htm>
 #'
 #'            Here is a quick summary:
-#'            perReader [data.frame] this data frame contains the performance results for each reader.
+#' \itemize{
+#'   \item {\code{perReader} 
+#'   [data.frame] this data frame contains the performance results for each reader.
 #'              Key variables of this data frame are AUCA, AUCB, AUCAminusAUCB and the corresponding
-#'              variances, confidence intervals, degrees of freedom and p-values.
-#'            Ustat [data.frame] this data frame contains the reader-average performance results.
+#'              variances, confidence intervals, degrees of freedom and p-values.}
+#'   \item {\code{Ustat}
+#'   [data.frame] this data frame contains the reader-average performance results.
 #'              The analysis results are based on U-statistics and the papers listed above.
 #'              Key variables of this data frame are AUCA, AUCB, AUCAminusAUCB and the corresponding
-#'              variances, confidence intervals, degrees of freedom and p-values.
-#'            MLEstat [data.frame] this data frame contains the reader-average performance results.
+#'              variances, confidence intervals, degrees of freedom and p-values.}
+#'   \item {\code{MLEstat}
+#'   [data.frame] this data frame contains the reader-average performance results.
 #'              The analysis results are based on V-statistics, which approximates the true distribution with
 #'              the empirical distribution. The empirical distribution equals the nonparametric MLE
 #'              estimate of the true distribution, which is also equivalent to the ideal bootstrap estimate.
 #'              Please refer to the papers listed above.
 #'              Key variables of this data frame are AUCA, AUCB, AUCAminusAUCB and the corresponding
 #'              variances, confidence intervals, degrees of freedom and p-values.
-#'            ROC [list] each object of this list is an object containing an ROC curve.
+#'   }
+#'   \item {\code{ROC}
+#'   [list] each object of this list is an object containing an ROC curve.
 #'              There is an ROC curve for every combination of reader and modality.
 #'              For every modality, there are also four average ROC curves. These are discussed in
-#'                Chen2014_Br-J-Radiol_v87p20140016
-#'                The diagonal average averages the reader-specific ROC curves along y = -x + b for b in (0,1)
-#'                The horizontal average averages the reader specific ROC curves along y = b for b in (0,1)
-#'                The vertical average averages the reader specific ROC curves along x = b for b in (0,1)
-#'                The pooled average ignores readerID and pools all the scores together to create one ROC curve.
-#'            varDecomp [list] the objects of this list are different decompositions of the total variance
+#'                Chen2014_Br-J-Radiol_v87p20140016.
+#'                The diagonal average averages the reader-specific ROC curves along y = -x + b for b in (0,1).
+#'                The horizontal average averages the reader specific ROC curves along y = b for b in (0,1).
+#'                The vertical average averages the reader specific ROC curves along x = b for b in (0,1).
+#'                The pooled average ignores readerID and pools all the scores together to create one ROC curve.}
+#'   \item {\code{varDecomp}
+#'   [list] the objects of this list are different decompositions of the total variance.
 #'              Please refer to Gallas2009_Commun-Stat-A-Theor_v38p2586 (framework paper).
 #'              The different decompositions are BCK, BDG, DBM, MS, OR.
-#'
+#'   }
+#' }
 #'
 #'
 #' @export
@@ -111,8 +114,6 @@ doIMRMC <- function(
   fileName = NULL,
   workDir = NULL,
   iMRMCjarFullPath = NULL,
-  stdout = NULL,
-  stderr = NULL,
   stripDatesForTests = FALSE){
 
   if (is.null(workDir)) {
@@ -140,10 +141,9 @@ doIMRMC <- function(
                 append = TRUE, sep = ", ")
 
   }
-
   if (is.null(iMRMCjarFullPath)) {
     iMRMCjar <- "iMRMC-v4.0.3.jar"
-    pkgPath = path.package("iMRMC", quiet = FALSE)
+    pkgPath <- path.package("iMRMC", quiet = FALSE)
     iMRMCjarFullPath <- file.path(pkgPath, "java", iMRMCjar)
 
     # This check is necessary for testthat tests that run in some
@@ -152,13 +152,30 @@ doIMRMC <- function(
       iMRMCjarFullPath = file.path(pkgPath, "inst","java", iMRMCjar)
     }
   }
-
+  
   # Run iMRMC
-  system2("java", args = c("-jar",
-                           iMRMCjarFullPath,
-                           fileName,
-                           file.path(workDir, "imrmcDir")),
-                           stdout = stdout, stderr = stderr)
+  desc <- tryCatch(
+    
+    system2(
+      "java",
+      args = c("-jar",
+               iMRMCjarFullPath,
+               fileName,
+               file.path(workDir, "imrmcDir")),
+      stdout = FALSE, stderr = TRUE),
+    
+    warning = function(w) {
+      cat("do_IMRMC WARNING\n")
+      warning(w)
+    },
+    error = function(e) {
+      cat("\ndoIMRMC ERROR\n")
+      cat("One possible reason is that you don't have java.\n")
+      cat("This software requires Java JDK 1.7 or higher.\n")
+      stop(e)
+    }
+
+  )
 
   # Retrieve the iMRMC results
   perReader <- utils::read.csv(file.path(workDir, "imrmcDir", "AUCperReader.csv"))
